@@ -1,15 +1,20 @@
+import uuid
+
 from django.db import models
 from django.db.models.deletion import SET_NULL
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
+from django_extensions.db.models import TimeStampedModel
 
-from munity.users.models import User
-from munity.models import MunityModel
+from ..users.models import User
+from ..workspaces.models import Workspace
 
-class Record(MunityModel):
-    previous_value = models.JSONField()
-    next_value = models.JSONField()
+class Record(TimeStampedModel):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
+    previous_value = models.JSONField(null=True)
+    diff_value = models.JSONField(null=True)
     user = models.ForeignKey(User, on_delete=SET_NULL, null=True)
+    workspace = models.ForeignKey(Workspace, on_delete=SET_NULL, null=True)
     product_object_id = models.UUIDField()
     product_content_type = models.ForeignKey(
         ContentType,
@@ -19,9 +24,4 @@ class Record(MunityModel):
         'product_content_type',
         'product_object_id',
     )
-
-    def get_absolute_url(self):
-        return f"/records/{self.id}"
-
-    def __str__(self):
-        return self.label
+    action = models.CharField(max_length=64, null=False, default="")
\ No newline at end of file
