@@ -1,6 +1,6 @@
 from django_filters import rest_framework as filters
 from rest_framework import serializers, viewsets
-from views import MunityViewSet
+from ..views import MunityViewSet
 
 from .models import Record
 
@@ -8,11 +8,13 @@ class RecordSerializer(serializers.ModelSerializer):
     class Meta:
         fields = [
             "id",
-            "previous_value",
+            "dif_value",
             "next_value",
             "created",
             "user",
-            "product",
+            "product_object_id",
+            "product_content_type",
+            "action",
         ]
         model = Record
 
@@ -21,7 +23,6 @@ class RecordsFilter(filters.FilterSet):
         fields = {
             "created": ["gt", "gte", "lt", "lte"],
             "user": ["exact"],
-            "product": ["exact"],
         }
         model = Record
 
