@@ -4,6 +4,8 @@ from rest_framework import serializers
 from django.db.models.query_utils import Q
 from .models import User, UserRoleWorkspace
 from rest_framework.exceptions import PermissionDenied
+from rest_framework.response import Response
+from rest_framework import status
 
 from ..views import MunityViewSet
 
@@ -29,6 +31,7 @@ class UserSerializer(serializers.ModelSerializer):
             "generic_groups",
             "user_role_workspaces",
             "password",
+            "phone_number"
         ]
         model = User
         extra_kwargs = {
@@ -50,19 +53,19 @@ class UserSerializer(serializers.ModelSerializer):
         if 'user_role_workspaces' in validated_data:
             user_role_workspaces_data = validated_data.pop('user_role_workspaces')
 
+            # add new rights
             user_new_workspaces = []
             for user_role_workspace_data in user_role_workspaces_data:
-                user_new_workspaces.append(user_role_workspace_data.get("workspace"))
-
-            # remove previous rights
-            UserRoleWorkspace.objects.filter(user=instance).exclude(workspace__in=user_new_workspaces).delete()
-
-            # add new rights
-            for user_role_workspace_data in user_role_workspaces_data:
+                workspace = user_role_workspace_data.get("workspace")
+                user_new_workspaces.append(workspace)
+                UserRoleWorkspace.objects.filter(user=instance).filter(workspace=workspace).delete()
                 UserRoleWorkspace.objects.update_or_create(
                     user=instance, **user_role_workspace_data
                 )
 
+            # remove revoked rights
+            UserRoleWorkspace.objects.filter(user=instance).exclude(workspace__in=user_new_workspaces).delete()
+
         user = super(self.__class__, self).update(instance, validated_data)
         if 'password' in validated_data:
             user.set_password(validated_data['password'])
@@ -134,9 +137,17 @@ class UsersViewSet(MunityViewSet):
             for user_role_workspace in user_role_workspaces:
                 if user_role_workspace.get('workspace') not in workspace_slugs:
                     raise PermissionDenied({"message":"You don't have permission to add user on this workspace"})
-        response = super().create(request, workspace_pk)
 
-        return response
+
+        if 'generic_groups' in request.data:
+            generic_groups = request.data.pop('generic_groups')
+            response = super().create(request, workspace_pk)
+            new_user = User.objects.filter(id=response.data.get("id")).first()
+            new_user.generic_groups.set(generic_groups)
+            new_user.save()
+            return Response(UserSerializer(new_user).data, status=status.HTTP_201_CREATED)
+
+        return super().create(request, workspace_pk)
 
     def update(self, request, workspace_pk=None, pk=None, partial=False):
         # we suppose that user as permission USER UPDATE for current workspace
@@ -152,15 +163,17 @@ class UsersViewSet(MunityViewSet):
             if edited_user.is_superuser:
                 raise PermissionDenied({"message":"You cannot edit superuser"})
 
-            accessible_workspaces = UserRoleWorkspace.objects.filter(user=self.request.user)
-            workspace_slugs = []
-            for accessible_workspace in accessible_workspaces:
-                workspace_slugs.append(accessible_workspace.workspace.slug)
+            # update role if needed
+            if 'user_role_workspaces' in request.data:
+                accessible_workspaces = UserRoleWorkspace.objects.filter(user=self.request.user)
+                workspace_slugs = []
+                for accessible_workspace in accessible_workspaces:
+                    workspace_slugs.append(accessible_workspace.workspace.slug)
 
-            user_role_workspaces = request.data.get('user_role_workspaces')
-            for user_role_workspace in user_role_workspaces:
-                if user_role_workspace.get('workspace') not in workspace_slugs:
-                    raise PermissionDenied({"message":"You don't have permission to change this access"})
+                user_role_workspaces = request.data.get('user_role_workspaces')
+                for user_role_workspace in user_role_workspaces:
+                    if user_role_workspace.get('workspace') not in workspace_slugs:
+                        raise PermissionDenied({"message":"You don't have permission to change this access"})
 
         response = super().update(request, pk=pk, workspace_pk=workspace_pk, partial=partial)
         return response
@@ -168,14 +181,27 @@ class UsersViewSet(MunityViewSet):
     # since user access workspaces by role, we have to adapt access permission through role and not workpace FK
     def get_queryset(self):
         model = self.serializer_class.Meta.model
+        queryset = model.objects.filter(disabled=False)
         if "workspace_pk" in self.kwargs:
-            return model.objects.filter(Q(id=self.request.user.id) | Q(user_role_workspaces__workspace=self.kwargs["workspace_pk"]))
+            # super user see all workspace users
+            if self.request.user.is_superuser:
+                return queryset.filter(Q(id=self.request.user.id) | Q(user_role_workspaces__workspace=self.kwargs["workspace_pk"])).distinct()
+            else:
+                # getting accessible workspaces
+                accessible_workspaces = UserRoleWorkspace.objects.filter(user=self.request.user)
+                workspace_slugs = []
+                for accessible_workspace in accessible_workspaces:
+                    workspace_slugs.append(accessible_workspace.workspace)
+                # get all related roles
+                return queryset.filter(
+                    user_role_workspaces__in=UserRoleWorkspace.objects.filter(workspace__in=workspace_slugs).filter(workspace__in=[self.kwargs["workspace_pk"]])
+                )
         # WE ARE ON OVERMIND!
         else:
             # super user see all overmind users
             if self.request.user.is_superuser:
                 # return model.objects.filter(Q(is_superuser=True) | Q(has_overmind_access=True))
-                return model.objects.all()
+                return queryset.all()
             # staff see user from his workspaces
             if self.request.user.has_overmind_access:
                 # getting accessible workspaces
@@ -184,7 +210,7 @@ class UsersViewSet(MunityViewSet):
                 for accessible_workspace in accessible_workspaces:
                     workspace_slugs.append(accessible_workspace.workspace)
                 # get all related roles
-                return model.objects.filter(
+                return queryset.filter(
                     user_role_workspaces__in=UserRoleWorkspace.objects.filter(workspace__in=workspace_slugs)
                 )
             # users see nothing
